==> openshift-model-monitoring-5.8.0-sources.jar: io/fabric8/openshift/api/model/monitoring/v1/NamespaceSelectorFluentImpl.java <==
package io.fabric8.openshift.api.model.monitoring.v1;

import java.lang.Integer;
import io.fabric8.kubernetes.api.builder.BaseFluent;
import java.util.ArrayList;
import java.util.Collection;
import java.lang.Object;
import java.util.List;
import java.lang.String;
import java.lang.Boolean;
import java.util.function.Predicate;

 /**
  * Generated
  */
public class NamespaceSelectorFluentImpl<A extends io.fabric8.openshift.api.model.monitoring.v1.NamespaceSelectorFluent<A>> extends io.fabric8.kubernetes.api.builder.BaseFluent<A> implements io.fabric8.openshift.api.model.monitoring.v1.NamespaceSelectorFluent<A>{
  public NamespaceSelectorFluentImpl() {
  }
  public NamespaceSelectorFluentImpl(io.fabric8.openshift.api.model.monitoring.v1.NamespaceSelector instance) {
    this.withAny(instance.getAny()); 
    this.withMatchNames(instance.getMatchNames()); 
  }
  private java.lang.Boolean any;
  private java.util.List<java.lang.String> matchNames = new java.util.ArrayList<java.lang.String>();
  public java.lang.Boolean getAny() {
    return this.any;
  }
  public A withAny(java.lang.Boolean any) {
    this.any=any; return (A) this;
  }
  public java.lang.Boolean hasAny() {
    return this.any != null;
  }
  public A addToMatchNames(java.lang.Integer index,java.lang.String item) {
    if (this.matchNames == null) {this.matchNames = new java.util.ArrayList<java.lang.String>();}
    this.matchNames.add(index, item);
    return (A)this;
  }
  public A setToMatchNames(java.lang.Integer index,java.lang.String item) {
    if (this.matchNames == null) {this.matchNames = new java.util.ArrayList<java.lang.String>();}
    this.matchNames.set(index, item); return (A)this;
  }
  public A addToMatchNames(java.lang.String... items) {
    if (this.matchNames == null) {this.matchNames = new java.util.ArrayList<java.lang.String>();}
    for (java.lang.String item : items) {this.matchNames.add(item);} return (A)this;
  }
  public A addAllToMatchNames(java.util.Collection<java.lang.String> items) {
    if (this.matchNames == null) {this.matchNames = new java.util.ArrayList<java.lang.String>();}
    for (java.lang.String item : items) {this.matchNames.add(item);} return (A)this;
  }
  public A removeFromMatchNames(java.lang.String... items) {
    for (java.lang.String item : items) {if (this.matchNames!= null){ this.matchNames.remove(item);}} return (A)this;
  }
  public A removeAllFromMatchNames(java.util.Collection<java.lang.String> items) {
    for (java.lang.String item : items) {if (this.matchNames!= null){ this.matchNames.remove(item);}} return (A)this;
  }
  public java.util.List<java.lang.String> getMatchNames() {
    return this.matchNames;
  }
  public java.lang.String getMatchName(java.lang.Integer index) {
    return this.matchNames.get(index);
  }
  public java.lang.String getFirstMatchName() {
    return this.matchNames.get(0);
  }
  public java.lang.String getLastMatchName() {
    return this.matchNames.get(matchNames.size() - 1);
  }
  public java.lang.String getMatchingMatchName(java.util.function.Predicate<java.lang.String> predicate) {
    for (java.lang.String item: matchNames) { if(predicate.test(item)){ return item;} } return null;
  }
  public java.lang.Boolean hasMatchingMatchName(java.util.function.Predicate<java.lang.String> predicate) {
    for (java.lang.String item: matchNames) { if(predicate.test(item)){ return true;} } return false;
  }
  public A withMatchNames(java.util.List<java.lang.String> matchNames) {
    if (matchNames != null) {this.matchNames = new java.util.ArrayList<java.lang.String>(); for (java.lang.String item : matchNames){this.addToMatchNames(item);}} else { this.matchNames = null;} return (A) this;
  }
  public A withMatchNames(java.lang.String... matchNames) {
    if (this.matchNames != null) {this.matchNames.clear();}
    if (matchNames != null) {for (java.lang.String item :matchNames){ this.addToMatchNames(item);}} return (A) this;
  }
  public java.lang.Boolean hasMatchNames() {
    return matchNames != null && !matchNames.isEmpty();
  }
  public A addNewMatchName(java.lang.String arg0) {
    return (A)addToMatchNames(new String(arg0));
  }
  public boolean equals(java.lang.Object o) {
    if (this == o) return true;
    if (o == null || getClass() != o.getClass()) return false;
    NamespaceSelectorFluentImpl that = (NamespaceSelectorFluentImpl) o;
    if (any != null ? !any.equals(that.any) :that.any != null) return false;
    if (matchNames != null ? !matchNames.equals(that.matchNames) :that.matchNames != null) return false;
    return true;
  }
  public int hashCode() {
    return java.util.Objects.hash(any,  matchNames,  super.hashCode());
  }
  
}

==> openshift-model-monitoring-5.11.1-sources.jar: io/fabric8/openshift/api/model/monitoring/v1/NamespaceSelectorFluentImpl.java <==
package io.fabric8.openshift.api.model.monitoring.v1;

import java.util.ArrayList;
import java.lang.String;
import java.util.LinkedHashMap;
import java.util.function.Predicate;
import java.lang.Integer;
import io.fabric8.kubernetes.api.builder.BaseFluent;
import java.util.Collection;
import java.lang.Object;
import java.util.List;
import java.lang.Boolean;
import java.util.Map;

 /**
  * Generated
  */
public class NamespaceSelectorFluentImpl<A extends io.fabric8.openshift.api.model.monitoring.v1.NamespaceSelectorFluent<A>> extends io.fabric8.kubernetes.api.builder.BaseFluent<A> implements io.fabric8.openshift.api.model.monitoring.v1.NamespaceSelectorFluent<A>{
  public NamespaceSelectorFluentImpl() {
  }
  public NamespaceSelectorFluentImpl(io.fabric8.openshift.api.model.monitoring.v1.NamespaceSelector instance) {
    this.withAny(instance.getAny()); 
    this.withMatchNames(instance.getMatchNames()); 
    this.withAdditionalProperties(instance.getAdditionalProperties());

  }
  private java.lang.Boolean any;
  private java.util.List<java.lang.String> matchNames = new java.util.ArrayList<java.lang.String>();
  private java.util.Map<java.lang.String,java.lang.Object> additionalProperties;
  public java.lang.Boolean getAny() {
    return this.any;
  }
  public A withAny(java.lang.Boolean any) {
    this.any=any; return (A) this;
  }
  public java.lang.Boolean hasAny() {
    return this.any != null;
  }
  public A addToMatchNames(java.lang.Integer index,java.lang.String item) {
    if (this.matchNames == null) {this.matchNames = new java.util.ArrayList<java.lang.String>();}
    this.matchNames.add(index, item);
    return (A)this;
  }
  public A setToMatchNames(java.lang.Integer index,java.lang.String item) {
    if (this.matchNames == null) {this.matchNames = new java.util.ArrayList<java.lang.String>();}
    this.matchNames.set(index, item); return (A)this;
  }
  public A addToMatchNames(java.lang.String... items) {
    if (this.matchNames == null) {this.matchNames = new java.util.ArrayList<java.lang.String>();}
    for (java.lang.String item : items) {this.matchNames.add(item);} return (A)this;
  }
  public A addAllToMatchNames(java.util.Collection<java.lang.String> items) {
    if (this.matchNames == null) {this.matchNames = new java.util.ArrayList<java.lang.String>();}
    for (java.lang.String item : items) {this.matchNames.add(item);} return (A)this;
  }
  public A removeFromMatchNames(java.lang.String... items) {
    for (java.lang.String item : items) {if (this.matchNames!= null){ this.matchNames.remove(item);}} return (A)this;
  }
  public A removeAllFromMatchNames(java.util.Collection<java.lang.String> items) {
    for (java.lang.String item : items) {if (this.matchNames!= null){ this.matchNames.remove(item);}} return (A)this;
  }
  public java.util.List<java.lang.String> getMatchNames() {
    return this.matchNames;
  }
  public java.lang.String getMatchName(java.lang.Integer index) {
    return this.matchNames.get(index);
  }
  public java.lang.String getFirstMatchName() {
    return this.matchNames.get(0);
  }
  public java.lang.String getLastMatchName() {
    return this.matchNames.get(matchNames.size() - 1);
  }
  public java.lang.String getMatchingMatchName(java.util.function.Predicate<java.lang.String> predicate) {
    for (java.lang.String item: matchNames) { if(predicate.test(item)){ return item;} } return null;
  }
  public java.lang.Boolean hasMatchingMatchName(java.util.function.Predicate<java.lang.String> predicate) {
    for (java.lang.String item: matchNames) { if(predicate.test(item)){ return true;} } return false;
  }
  public A withMatchNames(java.util.List<java.lang.String> matchNames) {
    if (matchNames != null) {this.matchNames = new java.util.ArrayList<java.lang.String>(); for (java.lang.String item : matchNames){this.addToMatchNames(item);}} else { this.matchNames = null;} return (A) this;
  }
  public A withMatchNames(java.lang.String... matchNames) {
    if (this.matchNames != null) {this.matchNames.clear();}
    if (matchNames != null) {for (java.lang.String item :matchNames){ this.addToMatchNames(item);}} return (A) this;
  }
  public java.lang.Boolean hasMatchNames() {
    return matchNames != null && !matchNames.isEmpty();
  }
  public A addNewMatchName(java.lang.String arg0) {
    return (A)addToMatchNames(new String(arg0));
  }
  public A addToAdditionalProperties(java.lang.String key,java.lang.Object value) {
    if(this.additionalProperties == null && key != null && value != null) { this.additionalProperties = new java.util.LinkedHashMap<java.lang.String,java.lang.Object>(); }
    if(key != null && value != null) {this.additionalProperties.put(key, value);} return (A)this;
  }
  public A addToAdditionalProperties(java.util.Map<java.lang.String,java.lang.Object> map) {
    if(this.additionalProperties == null && map != null) { this.additionalProperties = new java.util.LinkedHashMap<java.lang.String,java.lang.Object>(); }
    if(map != null) { this.additionalProperties.putAll(map);} return (A)this;
  }
  public A removeFromAdditionalProperties(java.lang.String key) {
    if(this.additionalProperties == null) { return (A) this; }
    if(key != null && this.additionalProperties != null) {this.additionalProperties.remove(key);} return (A)this;
  }
  public A removeFromAdditionalProperties(java.util.Map<java.lang.String,java.lang.Object> map) {
    if(this.additionalProperties == null) { return (A) this; }
    if(map != null) { for(Object key : map.keySet()) {if (this.additionalProperties != null){this.additionalProperties.remove(key);}}} return (A)this;
  }
  public java.util.Map<java.lang.String,java.lang.Object> getAdditionalProperties() {
    return this.additionalProperties;
  }
  public <K,V>A withAdditionalProperties(java.util.Map<java.lang.String,java.lang.Object> additionalProperties) {
    if (additionalProperties == null) { this.additionalProperties =  null;} else {this.additionalProperties = new java.util.LinkedHashMap<java.lang.String,java.lang.Object>(additionalProperties);} return (A) this;
  }
  public java.lang.Boolean hasAdditionalProperties() {
    return this.additionalProperties != null;
  }
  public boolean equals(java.lang.Object o) {
    if (this == o) return true;
    if (o == null || getClass() != o.getClass()) return false;
    NamespaceSelectorFluentImpl that = (NamespaceSelectorFluentImpl) o;
    if (any != null ? !any.equals(that.any) :that.any != null) return false;
    if (matchNames != null ? !matchNames.equals(that.matchNames) :that.matchNames != null) return false;
    if (additionalProperties != null ? !additionalProperties.equals(that.additionalProperties) :that.additionalProperties != null) return false;
    return true;
  }
  public int hashCode() {
    return java.util.Objects.hash(any,  matchNames,  additionalProperties,  super.hashCode());
  }
  
}
